@@ -9,8 +9,8 @@ module ActionMailer
   module VERSION
     MAJOR = 5
     MINOR = 2
-    TINY  = 3
-    PRE   = nil
+    TINY  = 4
+    PRE   = "3"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
