@@ -1,6 +1,9 @@
+# frozen_string_literal: true
+
 class Bulb < ActiveRecord::Base
-  default_scope { where(:name => 'defaulty') }
-  belongs_to :car, :touch => true
+  default_scope { where(name: "defaulty") }
+  belongs_to :car, touch: true
+  scope :awesome, -> { where(frickinawesome: true) }
 
   attr_reader :scope_after_initialize, :attributes_after_initialize
 
@@ -34,6 +37,18 @@ class CustomBulb < Bulb
   after_initialize :set_awesomeness
 
   def set_awesomeness
-    self.frickinawesome = true if name == 'Dude'
+    self.frickinawesome = true if name == "Dude"
+  end
+end
+
+class FunkyBulb < Bulb
+  before_destroy do
+    raise "before_destroy was called"
+  end
+end
+
+class FailedBulb < Bulb
+  before_destroy do
+    throw(:abort)
   end
 end
